@@ -1,4 +1,3 @@
-context("DAISIE_sumstats_rates")
 test_that("use simple ontogeny code", {
   out <- DAISIE_calc_sumstats_pcrates(
     pars = c(0.2, 0.2, 40, 0.1, 1),
@@ -9,7 +8,7 @@ test_that("use simple ontogeny code", {
                                  sea_level_amplitude = 0,
                                  sea_level_frequency = 0,
                                  island_gradient_angle = 0),
-    totaltime = 10,
+    total_time = 10,
     island_ontogeny = 1,
     extcutoff = 100,
     mainland_n = 1000,
